@@ -28,31 +28,23 @@
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
-#include <sys/stat.h>
-#include <sys/param.h>
 #include <netinet/in.h>
 
 #include <bluetooth/bluetooth.h>
 #include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
-#include <bluetooth/l2cap.h>
 #include <bluetooth/bnep.h>
 #include <bluetooth/sdp.h>
 
 #include <glib.h>
 #include <gdbus.h>
 
-#include "../src/dbus-common.h"
-
 #include "logging.h"
-#include "textfile.h"
 #include "glib-helper.h"
 
 #include "error.h"
 #include "common.h"
-#include "connection.h"
 
-#define NETWORK_PEER_INTERFACE "org.bluez.network.Peer"
+#define NETWORK_PEER_INTERFACE "org.bluez.Network"
 
 typedef enum {
 	CONNECTED,
@@ -131,12 +123,6 @@ static inline DBusMessage *not_connected(DBusMessage *msg)
 						"Device not connected");
 }
 
-static inline DBusMessage *no_pending_connect(DBusMessage *msg)
-{
-	return g_dbus_create_error(msg, ERROR_INTERFACE ".Failed",
-					"Device has no pending connect");
-}
-
 static inline DBusMessage *connection_attempt_failed(DBusMessage *msg, int err)
 {
 	return g_dbus_create_error(msg, ERROR_INTERFACE ".ConnectionAttemptFailed",
